@@ -1,20 +1,20 @@
 """
-Lisz Demo App
-=============
+lisz demo app data handling
+===========================
 
-This module provides common constants, functions and methods for the showcase/demo application `Lisz`, which is
+this module provides common constants, functions and methods for the showcase/demo application `Lisz`, which is
 demonstrating the usage of the GUI framework packages provided by the `ae namespace <https://ae.readthedocs.io>`__.
 
 
 usage demonstration of ae namespace portions
 --------------------------------------------
 
-The usage of the following ae namespace portions get demonstrated by this application:
+the usage of the following ae namespace portions get demonstrated by this application:
 
 * :mod:`ae.base`: basic constants and helper functions
 * :mod:`ae.files`: file collection, grouping and caching
 * :mod:`ae.deep`: deep data structure search and replace
-* :mod:`ae.i18n`: internationalization / Localization helpers
+* :mod:`ae.i18n`: internationalization / localization helpers
 * :mod:`ae.paths`: generic file path helpers
 * :mod:`ae.inspector`: inspection and debugging helper functions
 * :mod:`ae.updater`: application environment updater
@@ -27,12 +27,12 @@ The usage of the following ae namespace portions get demonstrated by this applic
 
 
 .. hint::
-    The Kivy variant of this demo app uses additionally the following ae namespace portions: :mod:`ae.kivy_auto_width`,
+    the Kivy variant of this demo app uses additionally the following ae namespace portions: :mod:`ae.kivy_auto_width`,
     :mod:`ae.kivy_dyn_chi`, :mod:`ae.kivy_help`, :mod:`ae.kivy_relief_canvas`, :mod:`ae.kivy_app` and
     :mod:`ae.kivy_user_prefs`.
 
 
-features of the Lisz demo app
+features of the lisz demo app
 -----------------------------
 
 * internationalization of texts, user messages, help texts, button/label texts (:mod:`ae.i18n`)
@@ -54,19 +54,19 @@ features of the Lisz demo app
 lisz application data model
 ---------------------------
 
-The Lisz demo app is managing a recursive item tree - a list of lists - that can be used e.g. as to-do or shopping list.
+fhe lisz demo app is managing a recursive item tree - a list of lists - that can be used e.g. as to-do or shopping list.
 
-To keep this demo app simple, the data managed by the Lisz application is a minimalistic tree structure that gets stored
-as an :ref:`application status`, without the need of any database. The root node and with that the whole recursive data
+to keep this demo app simple, the data managed by the lisz application is a minimalistic tree structure that gets stored
+as an :ref:`application status`, without the need of any database. the root node and with that the whole recursive data
 structure gets stored in the app state variable `root_node`.
 
-The root of the tree structure is a list of the type `LiszNode` containing list items of type `LiszItem`. A `LiszItem`
+the root of the tree structure is a list of the type `LiszNode` containing list items of type `LiszItem`. a `LiszItem`
 element represents a dict of the type `Dict[str, Any]`.
 
-Each `LiszItem` element of the tree structure is either a leaf or a node. And each node is a sub-list with a recursive
+each `LiszItem` element of the tree structure is either a leaf or a node. and each node is a sub-list with a recursive
 structure identical to the root node and of the type `LiszNode`.
 
-The following graph is showing an example data tree:
+the following graph is showing an example data tree:
 
 .. graphviz::
 
@@ -83,17 +83,17 @@ The following graph is showing an example data tree:
         rec3:CBA -> "Leaf Item CBA"
     }
 
-The above example tree structure is containing the root node items `A` (which is a leaf) and `C` (which is a sub-node).
+the above example tree structure is containing the root node items `A` (which is a leaf) and `C` (which is a sub-node).
 
-The node `C` consists of the items `CA` and `CB` where `CA` is a leaf and `CB` is a node.
+the node `C` consists of the items `CA` and `CB` where `CA` is a leaf and `CB` is a node.
 
-Finally the first item of the node `CB` is another sub-node with the leaf item `CBA`.
+the first item of the node `CB` is another sub-node with the leaf item `CBA`.
 
 
 GUI framework demo implementations
 ==================================
 
-The plan is to integrate the following GUI frameworks on top of the :class:`abstract base class <~.gui_app.MainAppBase>`
+the plan is to integrate the following GUI frameworks on top of the :class:`abstract base class <~.gui_app.MainAppBase>`
 (implemented in the :mod:`ae.gui_app` portion of the `ae namespace <https://ae.readthedocs.io>`__):
 
 * :mod:`Kivy <ae.kivy_app>` based on the `kivy framework <https://kivy.org>`__:
@@ -108,7 +108,7 @@ The plan is to integrate the following GUI frameworks on top of the :class:`abst
 * :mod:`pygobject <ae.pygobject_app>`
 * :mod:`AppJar <ae.appjar_app>`
 
-The main app base mixin class :class:`LiszDataMixin` provided by this module is used to manage the common data
+the main app base mixin class :class:`LiszDataMixin` provided by this module is used to manage the common data
 structures, functions and methods for the various demo applications variants based on :mod:`ae.gui_app` and the related
 GUI framework implementation portions (like e.g. :mod:`ae.kivy_app` and :mod:`ae.enaml_app`) of the ae namespace.
 
@@ -119,50 +119,50 @@ gui framework implementation variants
 kivy
 ----
 
-The `kivy lisz app <https://gitlab.com/ae-group/kivy_lisz>`__ is based on the `kivy framework <https://kivy.org>`__, a
+the `kivy lisz app <https://gitlab.com/ae-group/kivy_lisz>`__ is based on the `kivy framework <https://kivy.org>`__, a
 `pypi package <https://pypi.org/project/Kivy/>`__ documented `here <https://kivy.org/doc/stable/>`__.
 
 .. list-table::
 
-    * - .. figure:: ../_images/kivy_lisz_root.png
+    * - .. figure:: ../img/kivy_lisz_root.png
            :alt: root list of a dark themed kivy lisz app
            :scale: 30 %
-           :target: ../_images/kivy_lisz_root.png
+           :target: ../img/kivy_lisz_root.png
 
            kivy lisz app root list
 
-      - .. figure:: ../_images/kivy_lisz_fruits.png
+      - .. figure:: ../img/kivy_lisz_fruits.png
            :alt: fruits sub-list of a dark themed kivy lisz app
            :scale: 30 %
-           :target: ../_images/kivy_lisz_fruits.png
+           :target: ../img/kivy_lisz_fruits.png
 
            fruits sub-list
 
-      - .. figure:: ../_images/kivy_lisz_fruits_light.png
+      - .. figure:: ../img/kivy_lisz_fruits_light.png
            :alt: fruits sub-list of a light themed kivy lisz app
            :scale: 30 %
-           :target: ../_images/kivy_lisz_fruits_light.png
+           :target: ../img/kivy_lisz_fruits_light.png
 
            using light theme
 
-    * - .. figure:: ../_images/kivy_lisz_user_prefs.png
-           :alt: user preferences drop down
+    * - .. figure:: ../img/kivy_lisz_user_prefs.png
+           :alt: user preferences dropdown
            :scale: 30 %
-           :target: ../_images/kivy_lisz_user_prefs.png
+           :target: ../img/kivy_lisz_user_prefs.png
 
            lisz user preferences
 
-      - .. figure:: ../_images/kivy_lisz_color_editor.png
+      - .. figure:: ../img/kivy_lisz_color_editor.png
            :alt: kivy lisz color editor
            :scale: 30 %
-           :target: ../_images/kivy_lisz_color_editor.png
+           :target: ../img/kivy_lisz_color_editor.png
 
            kivy lisz color editor
 
-      - .. figure:: ../_images/kivy_lisz_font_size_big.png
+      - .. figure:: ../img/kivy_lisz_font_size_big.png
            :alt: lisz app using bigger font size
            :scale: 30 %
-           :target: ../_images/kivy_lisz_font_size_big.png
+           :target: ../img/kivy_lisz_font_size_big.png
 
            bigger font size
 
@@ -176,24 +176,24 @@ kivy wish list
 enaml
 -----
 
-The `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is based on the
+the `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is based on the
 `enaml framework <https://pypi.org/project/enaml/>`__, a `pypi package <https://pypi.org/project/enaml/>`__ documented
 `here at ReadTheDocs <https://enaml.readthedocs.io/en/latest/>`__.
 
 .. list-table::
     :widths: 27 66
 
-    * - .. figure:: ../_images/enaml_lisz_fruits_sub_list.png
+    * - .. figure:: ../img/enaml_lisz_fruits_sub_list.png
            :alt: fruits sub-list of dark themed enaml lisz app
            :scale: 27 %
-           :target: ../_images/enaml_lisz_fruits_sub_list.png
+           :target: ../img/enaml_lisz_fruits_sub_list.png
 
            enaml/qt lisz app
 
-      - .. figure:: ../_images/enaml_lisz_light_landscape.png
+      - .. figure:: ../img/enaml_lisz_light_landscape.png
            :alt: fruits sub-list of a light themed enaml lisz app in landscape
            :scale: 66 %
-           :target: ../_images/enaml_lisz_light_landscape.png
+           :target: ../img/enaml_lisz_light_landscape.png
 
            light themed in landscape
 
@@ -201,18 +201,18 @@ The `enaml lisz demo app <https://gitlab.com/ae-group/enaml_lisz>`__ is based on
 automatic update of widget attributes
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-Dependencies have to be executed/read_from, so e.g. the icon attribute will not be updated if app.app_state_light_theme
+dependencies have to be executed/read_from, so e.g. the icon attribute will not be updated if app.app_state_light_theme
 gets changed::
 
     icon << main_app.cached_icon('font_size') or app.app_state_light_theme
 
-In contrary the icon will be updated by the following two statements::
+in contrary the icon will be updated by the following two statements::
 
     icon << main_app.cached_icon('font_size') if app.app_state_light_theme else main_app.cached_icon('font_size')
     icon << app.app_state_light_theme == None or main_app.cached_icon('font_size')
 
 KeyEvent implementation based on this SO answer posted by the enamlx author frmdstryr/Jairus Martin:
-https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-enaml. Alternative and more complete
+https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-enaml. alternative and more complete
 implementation can be found in the enamlx package (https://github.com/frmdstryr/enamlx).
 
 
@@ -236,7 +236,7 @@ from ae.core import DEBUG_LEVEL_VERBOSE
 from ae.gui_app import id_of_flow, flow_action, flow_key, flow_path_strip, replace_flow_action  # type: ignore
 
 
-__version__ = '0.2.47'
+__version__ = '0.3.47'
 
 
 FLOW_PATH_ROOT_ID = '^^^^'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -264,7 +264,7 @@ def check_item_id(item_id: str) -> str:
     """ check if the passed item id string is valid.
 
     :param item_id:             item id to check.
-    :return:                    "" if all chars in the passed item id are valid,
+    :return:                    "" if all chars in the specified :paramref:`.item_id` argument are valid,
                                 else one of the translated message strings.
     """
     msg = get_f_string("item id '{item_id}' ")
@@ -296,17 +296,17 @@ def correct_item_id(item_id: str) -> str:
 def flow_path_items_from_text(text: str) -> Tuple[str, str, LiszNode]:
     """ parse and interpret text block for (optional) flow path text and node data (in pprint.pformat/repr format).
 
-    :param text:                text block to be parsed. The text block can optionally be prefixed with a extra
+    :param text:                text block to be parsed. the text block can optionally be prefixed with an extra
                                 line (separated by a new line '\\n' character) containing the destination flow path
                                 in text format (using FLOW_PATH_TEXT_SEP to separate the flow path items).
 
-                                The (rest of the) text block represents the node/item data in one of the
+                                the (rest of the) text block represents the node/item data in one of the
                                 following formats:
 
                                 * single text line (interpreted as single leaf item).
                                 * multiple text lines (interpreted as multiple leaf items).
-                                * dict repr string (starting with '{' character).
-                                * list repr string (starting with '[' character).
+                                * dict repr string, starting with '{' character.
+                                * list repr string, starting with '[' character.
 
     :return:                    tuple of
                                 error message (empty string if no error occurred),
@@ -369,10 +369,10 @@ def item_unsel_filter(item: LiszItem) -> bool:
 
 class LiszDataMixin:
     """ lisz data model - independent from used GUI framework. """
-    root_node: LiszNode = list()    #: root of lisz data structure
+    root_node: LiszNode = []        #: root of lisz data structure
     current_node_items: LiszNode    #: node item data of the current node / sub list (stored as app state via root_node)
     filtered_indexes: List[int]     #: indexes of the filtered/displayed items in the current node
-    # additional app-common attributes (never directly referenced/needed, KEEP for completeness/documentation).
+    # additional app-common attributes (never directly referenced/needed, keep for completeness/documentation).
     filter_selected: bool = False   #: True to hide/filter selected node items
     filter_unselected: bool = False  #: True to hide/filter unselected node items
 
@@ -414,12 +414,11 @@ class LiszDataMixin:
             # overwrite inserted nid because edit_validate(used to ensure proper id and no dup) creates new nid
             node_to_add_to[new_item_index] = nid
 
-        elif want_node:
-            # if want node then first check if error is dup error and fixable
+        elif want_node:             # then first check if error is dup error and fixable
             item_idx = self.find_item_index(item_id, searched_node=node_to_add_to)
             if item_idx >= 0:                                   # found the blocking/duplicate item id
                 if 'node' not in node_to_add_to[item_idx]:
-                    node_to_add_to[item_idx]['node'] = list()   # convert blocking item from leaf to node
+                    node_to_add_to[item_idx]['node'] = []       # convert blocking item from leaf to node
                 err_msg = ("(ignorable) " + err_msg) if self.debug_level else ""
                 sub_err = self.add_items(nid['node'], node_to_add_to=node_to_add_to[item_idx]['node'])
                 if sub_err:                                     # add (ignorable?) errors from sub-node adds
@@ -438,7 +437,7 @@ class LiszDataMixin:
         if node_to_add_to is None:
             node_to_add_to = self.current_node_items
 
-        errors = list()
+        errors = []
         for item in reversed(items):
             err_msg = self.add_item(item, node_to_add_to=node_to_add_to)
             if err_msg:
@@ -485,7 +484,7 @@ class LiszDataMixin:
         if parent_node is None:
             parent_node = self.current_node_items
 
-        del_items = list()
+        del_items = []
         for item_id in item_ids:
             nid = self.item_by_id(item_id, searched_node=parent_node)
             if node_only:
@@ -538,16 +537,16 @@ class LiszDataMixin:
                 return ""
             nid = dict(id=new_id)
             if want_node:
-                nid['node'] = list()        # type: ignore   # mypy not supports recursive types see issue #731
+                nid['node'] = []            # type: ignore   # mypy not supports recursive types see issue #731
             parent_node.insert(new_item_index, nid)
 
         else:                               # edit item
             nid = parent_node[old_item_index]
             if new_id:
                 nid['id'] = new_id
-            if want_node is not None and want_node != ('node' in nid):  # NOTE: != has lower priority than in operator
+            if want_node is not None and want_node != ('node' in nid):  # note: != has lower priority than in operator
                 if want_node:
-                    nid['node'] = list()    # type: ignore   # mypy not supports recursive types see issue #731
+                    nid['node'] = []        # type: ignore   # mypy not supports recursive types see issue #731
                 elif nid['node']:           # let user confirm node deletion of non-empty nid['node']
                     return 'request_delete_confirmation_for_node'
                 else:
@@ -568,7 +567,7 @@ class LiszDataMixin:
         if not node:
             node = self.flow_path_node(flow_path)
         flow_path = flow_path_strip(flow_path)
-        file_name = NODE_FILE_PREFIX + (norm_name(flow_key(flow_path[-1])) if flow_path else
+        file_name = NODE_FILE_PREFIX + (norm_name(flow_key(flow_path[-1]), allow_num_prefix=True) if flow_path else
                                         FLOW_PATH_ROOT_ID) + NODE_FILE_EXT
 
         try:
@@ -595,13 +594,13 @@ class LiszDataMixin:
         return -1
 
     def flow_key_text(self, flow_id: str, landscape: bool) -> str:
-        """ determine shortest possible text fragment of the passed flow key that is unique in the current node.
+        """ determine the shortest possible text fragment of the passed flow key that is unique in the current node.
 
-        Used to display unique part of the key of the focused item/node.
+        used to display unique part of the key of the focused item/node.
 
         :param flow_id:         flow id to get key to check from (pass the observed value to update GUI automatically,
                                 either self.app_state_flow_id or self.app_states['flow_id']).
-        :param landscape:       True if window has landscape shape (resulting in larger abbreviation). Pass the observed
+        :param landscape:       True if window has landscape shape (resulting in larger abbreviation). pass the observed
                                 attribute, mostly situated in the framework_win (e.g. self.framework_win.landscape).
         :return:                display text containing flow key.
         """
@@ -624,7 +623,7 @@ class LiszDataMixin:
         :param skip_check:      pass True to skip the check if the flow path exists in the current self.root_node.
         :return:                flow path list.
         """
-        flow_path = list()
+        flow_path = []
         if text not in ('', FLOW_PATH_ROOT_ID):
             node = self.root_node
             for part in text.split(FLOW_PATH_TEXT_SEP):
@@ -634,7 +633,7 @@ class LiszDataMixin:
                     for nid in node:
                         if nid['id'].startswith(part) and 'node' in nid:
                             flo_key = nid['id']
-                            node = nid['node']  # type: ignore   # mypy not supports recursive types see issue #731
+                            node = nid['node']
                             break
                     else:
                         break       # should actually not be needed, will repair data tree errors
@@ -646,7 +645,7 @@ class LiszDataMixin:
 
         :param flow_path:       flow path list.
         :param create:          pass True to create missing nodes.
-                                Only on False this method will return empty list on invalid/broken flow_path.
+                                only on False this method will return empty list on invalid/broken flow_path.
         :return:                node list at flow_path (if found -or- created is True and no-creation-errors)
                                 or empty list (if flow_path not found and created is False or on creation error).
         """
@@ -661,9 +660,9 @@ class LiszDataMixin:
                 item = self.item_by_id(node_id, searched_node=node)
                 if item not in node or 'node' not in item:
                     if not create or item not in node and self.add_item(item, node_to_add_to=node):
-                        return list()           # on error RETURN empty list
+                        return []               # on error RETURN empty list
                     if 'node' not in item:
-                        item['node'] = list()
+                        item['node'] = []
                 node = item['node']
 
         return node
@@ -673,8 +672,8 @@ class LiszDataMixin:
 
         :return:                list of flow path texts of all nodes apart from the current one.
         """
-        paths: List[str] = list()
-        deeper_flow_path: List[str] = list()
+        paths: List[str] = []
+        deeper_flow_path: List[str] = []
 
         def append_node_path_texts(node):
             """ recursively collect all available nodes (possible flow paths) """
@@ -695,7 +694,7 @@ class LiszDataMixin:
         """ generate shortened display text from the passed flow path.
 
         :param flow_path:       flow path list.
-        :param min_len:         minimum length of node ids (flow id keys). Pass zero value to not shorten ids.
+        :param min_len:         minimum length of node ids (flow id keys). pass zero value to not shorten ids.
         :param display_root:    pass True to return FLOW_PATH_ROOT_ID on empty/root path.
         :param separator:       path item separator (default=FLOW_PATH_TEXT_SEP).
         :return:                shortened display text string of the passed flow path (which can be converted back
@@ -703,7 +702,7 @@ class LiszDataMixin:
         """
         path_nid = None         # suppress Pycharm PyUnboundLocalVariable inspection warning
         shortening = bool(min_len)
-        shortened_ids = list()
+        shortened_ids = []
         node = self.root_node
         for flow_id in flow_path:
             if flow_action(flow_id) != 'enter':
@@ -720,7 +719,7 @@ class LiszDataMixin:
 
             shortened_ids.append(node_id[:id_len])
             if path_nid and 'node' in path_nid:     # prevent error in quick jump to root
-                node = path_nid['node']             # type: ignore   # mypy not supports recursive types see issue #731
+                node = path_nid['node']
 
         return separator.join(shortened_ids) if shortened_ids else (FLOW_PATH_ROOT_ID if display_root else '')
 
@@ -747,15 +746,18 @@ class LiszDataMixin:
         return super().global_variables(FLOW_PATH_ROOT_ID=FLOW_PATH_ROOT_ID, **patches)  # type: ignore
 
     def importable_node_files(self, folder_path: str = ".") -> NodeFilesInfo:
-        """ load and check all nodes found in the documents app folder of this app.
+        """ load and check all nodes found in the app folder documents of this app.
 
         :param folder_path: path to the folder where the node files are situated (def=current working directory).
         :return:            list of node file tuples of (node_name, node, file_path, error-message).
         """
-        node_file_info_tuples = list()
+        node_file_info_tuples = []
         for node_file in os.scandir(folder_path):
+            # noinspection PyUnresolvedReferences
             file_name = node_file.name
+            # noinspection PyUnresolvedReferences
             if file_name.endswith(NODE_FILE_EXT) and node_file.is_file():
+                # noinspection PyUnresolvedReferences
                 node_file_info_tuples.append(self.import_file_info(node_file.path))
         return node_file_info_tuples
 
@@ -764,7 +766,7 @@ class LiszDataMixin:
         """ load node file and determine node content.
 
         :param file_path:   path to the node file to import.
-        :param node_name:   optional name/id of the parent node name. If not passed then it will be determined
+        :param node_name:   optional name/id of the parent node name. if not passed then it will be determined
                             from the file name (removing :data:`NODE_FILE_PREFIX` and file extension).
         :return:            node file info tuple as: (node name, node-data or empty list, file path, error message).
         """
@@ -775,19 +777,19 @@ class LiszDataMixin:
 
         content = read_file_text(file_path, error_handling='strict')
         if content is None:
-            return node_name, list(), file_path, "file load error"
+            return node_name, [], file_path, "file load error"
 
         file_len = len(content)
         if file_len > IMPORT_NODE_MAX_FILE_LEN:
-            return (node_name, list(), file_path,
+            return (node_name, [], file_path,
                     f"import file is bigger than {IMPORT_NODE_MAX_FILE_LEN} bytes ({file_len})")
 
         err_msg, _, node = flow_path_items_from_text(content)       # ignore optional flow path given in 1st line
         if err_msg or not node:
-            return node_name, list(), file_path, "invalid file content or empty file; ERR=" + err_msg
+            return node_name, [], file_path, "invalid file content or empty file; ERR=" + err_msg
 
         if len(node) > IMPORT_NODE_MAX_ITEMS:
-            return (node_name, list(), file_path,
+            return (node_name, [], file_path,
                     f"import file contains more than {IMPORT_NODE_MAX_ITEMS} items ({len(node)})")
 
         return node_name, node, file_path, ""
@@ -800,7 +802,7 @@ class LiszDataMixin:
         :param item_index:      list index in the destination node where the items have to be inserted (default=0).
         :return:                empty string if all items of node got imported correctly, else error message string.
         """
-        error_messages = list()
+        error_messages = []
         for item in node:
             err_msg = self.edit_validate(-1, item['id'], parent_node=parent, new_item_index=item_index)
             if err_msg:
@@ -918,7 +920,7 @@ class LiszDataMixin:
     def on_filter_toggle(self, toggle_attr: str, _event_kwargs: Dict[str, Any]) -> bool:
         """ toggle filter on click of either the selected or the unselected filter button.
 
-        Note that the inverted filter may be toggled to prevent both filters active.
+        note that the inverted filter may be toggled to prevent both filters active.
 
         :param toggle_attr:     specifying the filter button to toggle, either 'filter_selected' or 'filter_unselected'.
         :param _event_kwargs:   unused.
@@ -979,8 +981,8 @@ class LiszDataMixin:
                                 non-empty node).
         :return:                True to process/change flow id.
 
-        This flow change event can be used alternatively to :meth:`~LiszDataMixin.on_item_sel_toggle`
-        for more sophisticated Lisz app implementations, like e.g. the
+        this flow change event can be used alternatively to :meth:`~LiszDataMixin.on_item_sel_toggle`
+        for more sophisticated lisz app implementations, like e.g. the
         `kivy lisz demo app <https://gitlab.com/ae-group/kivy_lisz>`__ .
         """
         node_idx = self.find_item_index(item_id)
@@ -1069,9 +1071,9 @@ class LiszDataMixin:
         :param event_kwargs:    extra arguments specifying extract options (only `extract_type` is mandatory):
 
                                 `extract_type` specifies extract destination and an optional filter on un-/selected
-                                items. The first part defines the extract action (copy/cut/delete/export/share)
+                                items. the first part defines the extract action (copy/cut/delete/export/share)
                                 and an optional second part (separated by an underscore) the filter.
-                                E.g. the following string values can be passed for a 'copy' extract action:
+                                e.g. the following string values can be passed for a 'copy' extract action:
 
                                 * 'copy' is copying all items of the specified node to the clipboard.
                                 * 'copy_sel' is copying only the selected items of the node to the clipboard.
@@ -1128,11 +1130,9 @@ class LiszDataMixin:
     def on_node_jump(self, flow_path_text: str, event_kwargs: Dict[str, Any]) -> bool:
         """ FlowButton clicked event handler restoring flow path from the flow key.
 
-        Used to jump to node specified by the flow path text in the passed flow_id key.
-
         :param flow_path_text:  flow path text (identifying where to jump to).
         :param event_kwargs:    event arguments (used to reset flow id).
-        :return:                True to process/change flow.
+        :return:                always True to process/change flow.
         """
         flow_path = self.flow_path_from_text(flow_path_text)
 
@@ -1183,7 +1183,7 @@ class LiszDataMixin:
             self._refreshing_data = False
 
     def refresh_current_node_items_from_flow_path(self):
-        """ refresh current node including the depending display node. """
+        """ refresh current node including the depending on display node. """
         self.current_node_items = self.flow_path_node()
 
     def shrink_node_size(self, node: LiszNode, item_filter: Optional[Callable[[LiszItem], bool]] = None,
@@ -1192,11 +1192,11 @@ class LiszDataMixin:
 
         :param node:            start or root node to shrink (in-place!).
         :param item_filter:     pass callable to remove items from the passed node and its sub-nodes.
-                                The callable is getting passed each item as argument and has to return True
+                                the callable is getting each item as argument and has to return True
                                 to remove it from its node.
         :param recursive:       pass False if only the passed start node has to be shrunk.
         """
-        del_items = list()
+        del_items = []
 
         for item in node:
             is_node = 'node' in item
@@ -1217,15 +1217,15 @@ class LiszDataMixin:
                      sub_ids: Optional[List[str]] = None) -> List[str]:
         """ return item names/ids of the specified items including their sub-node items (if exists and recursive==True).
 
-        Used to determine the affected item ids if user want to delete or de-/select the sub-items of
+        used to determine the affected item ids if user want to delete or de-/select the sub-items of
         the item(s) specified by the passed arguments.
 
         :param node:            searched node, if not passed use the current node as default.
         :param item_ids:        optional item id filter, if passed only items with an id in this tuple will be returned.
-                                This filter will not be used for sub-node filtering (if recursive==True).
+                                this filter will not be used for sub-node filtering (if recursive==True).
         :param leaves_only:     pass False to also include/return node item ids.
         :param hide_sel_val:    pass False/True to exclude un-/selected leaf items from the returned list of ids.
-                                If None or not passed then all found items will be included.
+                                if None or not passed then all found items will be included.
         :param recursive:       pass False if only the passed start node has to be investigated/included.
         :param sub_ids:         already found sub item ids (used for the recursive calls of this method).
         :return:                list of found item ids.
@@ -1233,9 +1233,9 @@ class LiszDataMixin:
         if node is None:
             node = self.current_node_items
         if sub_ids is None:
-            sub_ids = list()
+            sub_ids = []
 
-        for item in node:           # type: ignore # mypy does not recognize that node cannot be None
+        for item in node:
             if item_ids and item['id'] not in item_ids:
                 continue
             if (not leaves_only) if 'node' in item else (hide_sel_val is None or bool(item.get('sel')) != hide_sel_val):
